<div align="center">

![Ikabot Banner](assets/banner.png)

[![Downloads](https://static.pepy.tech/badge/ikabot)](https://pepy.tech/project/ikabot) ![GitHub Repo stars](https://img.shields.io/github/stars/Ikabot-Collective/ikabot?style=flat) ![licence](https://img.shields.io/github/license/Ikabot-Collective/ikabot?style=flat)

Ikabot is a cross-platform Python program that enhances your Ikariam game by offering premium features for free, focusing on city management, warfare strategies, and streamlined alerts.

-[Discover the features](https://github.com/Ikabot-Collective/ikabot/wiki/Features)- 
</div>

## Getting Started
- Checkout the [Getting Started guide](https://github.com/Ikabot-Collective/ikabot/wiki/Getting-Started)

## Contribution Guidelines

- Before contributing code, read the [Contribution Guidelines](.github/CONTRIBUTING.md)
  - GitHub issues are for bugs and feature requests.
  - For questions, help and chat in general, join our Discord Server:

     [![Discord server!](https://invidget.switchblade.xyz/3hyxPRj)](http://discord.gg/3hyxPRj)

  
- Want to say thanks?
  - Hit the :star: Star :star: button

## Contributors

This project exists thanks to all the people who contribute.

<a href="https://github.com/Ikabot-Collective/ikabot/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=Ikabot-Collective/ikabot" />
</a>

## Screenshots

![Ikabot Screenshot](assets/screenshot-1.jpg)
